@@ -489,7 +489,9 @@ test_discovery_versioned_ignore_older (void)
 
 int main(int argc, char *argv[])
 {
+#if !GLIB_CHECK_VERSION (2, 35, 0)
         g_type_init ();
+#endif
         g_test_init (&argc, &argv, NULL);
 
         g_test_add_func ("/functional/resource-group/discovery/ssdp:all",
