@@ -250,7 +250,9 @@ void test_bgo682099 (void)
 
 int main (int argc, char *argv[])
 {
+#if !GLIB_CHECK_VERSION (2, 35, 0)
         g_type_init ();
+#endif
         g_test_init (&argc, &argv, NULL);
 
         if (g_test_slow ()) {
